@@ -41,18 +41,6 @@ class Auth():
         self.access_obj=None
         self.lock=False
 
-    def getApiKey(self,username,password):
-        url=os.path.join( 'sso', 'api', 'getapikey' )
-        params={
-            'username':username,
-            'password':password
-        }
-        r=self.client( url, params, "POST", authorization_required = False)
-        if r.status_code in range(400,500):
-            return AdamApiError(r['error'])
-        else:
-            return r['api_key']
-
     def authorize( self ):
         """
         try to autorize the adamapi to the target adam instance
@@ -73,6 +61,12 @@ class Auth():
             self.access_obj= res
             return res
 
+    def getAuthToken(self):
+        return {
+                "authorization_token" : self.access_obj["access_token"],
+                "expire_at" : self.access_obj["access_token"]
+                }
+
     def _check( self ):
         """
         verify if the user key and the adam url are valid
@@ -178,7 +172,7 @@ class Auth():
         self.access_obj = self.client(os.path.join( 'apis','v1', 'authorization', 'refresh' ), params, 'PUT').json()
         self.lock=False
 
-    def client( self, query, params, request_type, authorization_required = True , force_raise = False ):
+    def client( self, query, params, request_type, authorization_required = True , force_raise = False ,enable_stream=False):
         """
         The client method that perform the request appending the Authorization header
         """
@@ -201,13 +195,13 @@ class Auth():
         if request_type not in [ 'GET', 'POST', 'PUT' ]:
             raise AdamApiError( "Request type not supported" )
 
-        logger.info( "%s request started", request_type )
+        logger.debug( "%s request started", request_type )
         if "\\" in url:
             url = url.replace("\\","/")
         if request_type == 'GET':
             par = params.copy()
             par["token"] = self.access_obj["access_token"]
-            r=requests.get( url, params=par )
+            r=requests.get( url, params=par ,stream=enable_stream)
         elif request_type == 'POST':
             par = params.copy()
             par["token"] = self.access_obj["access_token"]
