@@ -39,10 +39,9 @@ class Search():
         Product Catalogue Search
         @ datasetId, the dataseId ,required
         @ startDate, search start date (%Y-%m-%d)
-        @ completionDate, search end date (%Y-%m-%d)
+        @ endDate, search end date (%Y-%m-%d)
         @ maxRecords, number of result showed
         @ startIndex, index of the first result to start showin
-        @ outputAttributes, list of attributes desired on the output dictionary
         """
         params={}
         url=os.path.join( 'apis','v2','opensearch',datasetId.split(":",1)[0],'records')
@@ -56,11 +55,9 @@ class Search():
                     params[par] = kwargs[par]
                 elif type(kwargs[par]) is dict:
                     params[par] = json.dumps(kwargs[par])
-            elif par == 'outputAttributes':
-                params[ 'attributes' ] = ','.join( kwargs[par] )
             elif par == 'startDate' and isinstance( kwargs[par], datetime ):
                 params[ 'startDate' ] = kwargs[par].strftime( '%Y-%m-%dT%H:%M:%SZ' )
-            elif par == 'completionDate' and isinstance( kwargs[par], datetime ):
+            elif par == 'endDate' and isinstance( kwargs[par], datetime ):
                 params[ 'completionDate' ] = kwargs[par].strftime( '%Y-%m-%dT%H:%M:%SZ' )
             elif par == 'startIndex':
                 params['page'] = kwargs[par]
